@@ -27,18 +27,19 @@ class PCABackgroundPreparationModule(ProcessingModule):
     Pipeline module for preparing the images for a PCA-based background subtraction.
     """
 
-    __author__ = 'Tomas Stolker, Silvan Hunziker'
+    __author__ = "Tomas Stolker, Silvan Hunziker"
 
     @typechecked
-    def __init__(self,
-                 name_in: str,
-                 image_in_tag: str,
-                 star_out_tag: str,
-                 subtracted_out_tag: str,
-                 background_out_tag: str,
-                 dither: Union[Tuple[int, int, int],
-                               Tuple[int, None, Tuple[float, float]]],
-                 combine: str = 'mean') -> None:
+    def __init__(
+        self,
+        name_in: str,
+        image_in_tag: str,
+        star_out_tag: str,
+        subtracted_out_tag: str,
+        background_out_tag: str,
+        dither: Union[Tuple[int, int, int], Tuple[int, None, Tuple[float, float]]],
+        combine: str = "mean",
+    ) -> None:
         """
         Parameters
         ----------
@@ -78,7 +79,7 @@ class PCABackgroundPreparationModule(ProcessingModule):
         self.m_background_out_port = self.add_output_port(background_out_tag)
 
         if len(dither) != 3:
-            raise ValueError('The \'dither\' argument should contain three values.')
+            raise ValueError("The 'dither' argument should contain three values.")
 
         self.m_dither = dither
         self.m_combine = combine
@@ -86,53 +87,78 @@ class PCABackgroundPreparationModule(ProcessingModule):
     @typechecked
     def _prepare(self) -> Tuple[np.ndarray, np.ndarray]:
 
-        nframes = self.m_image_in_port.get_attribute('NFRAMES')
+        nframes = self.m_image_in_port.get_attribute("NFRAMES")
 
-        cube_mean = np.zeros((nframes.shape[0],
-                              self.m_image_in_port.get_shape()[2],
-                              self.m_image_in_port.get_shape()[1]))
+        cube_mean = np.zeros(
+            (
+                nframes.shape[0],
+                self.m_image_in_port.get_shape()[2],
+                self.m_image_in_port.get_shape()[1],
+            )
+        )
 
         count = 0
         for i, item in enumerate(nframes):
-            if self.m_combine == 'mean':
-                cube_mean[i, ] = np.mean(self.m_image_in_port[count:count+item, ], axis=0)
+            if self.m_combine == "mean":
+                cube_mean[i,] = np.mean(
+                    self.m_image_in_port[count : count + item,], axis=0
+                )
 
-            elif self.m_combine == 'median':
-                cube_mean[i, ] = np.median(self.m_image_in_port[count:count+item, ], axis=0)
+            elif self.m_combine == "median":
+                cube_mean[i,] = np.median(
+                    self.m_image_in_port[count : count + item,], axis=0
+                )
 
             count += item
 
         if self.m_dither[1] is None:
-            dither_x = self.m_image_in_port.get_attribute('DITHER_X')
-            dither_y = self.m_image_in_port.get_attribute('DITHER_Y')
+            dither_x = self.m_image_in_port.get_attribute("DITHER_X")
+            dither_y = self.m_image_in_port.get_attribute("DITHER_Y")
 
-            star = np.logical_and(dither_x == self.m_dither[2][0],
-                                  dither_y == self.m_dither[2][1])
+            star = np.logical_and(
+                dither_x == self.m_dither[2][0], dither_y == self.m_dither[2][1]
+            )
 
             bg_frames = np.invert(star)
 
         else:
             bg_frames = np.ones(nframes.shape[0], dtype=bool)
 
-            for i in range(self.m_dither[2]*self.m_dither[1],
-                           np.size(nframes),
-                           self.m_dither[1]*self.m_dither[0]):
+            for i in range(
+                self.m_dither[2] * self.m_dither[1],
+                np.size(nframes),
+                self.m_dither[1] * self.m_dither[0],
+            ):
 
-                bg_frames[i:i+self.m_dither[1]] = False
+                bg_frames[i : i + self.m_dither[1]] = False
 
         return bg_frames, cube_mean
 
     @typechecked
-    def _separate(self,
-                  bg_frames: np.ndarray,
-                  bg_indices: np.ndarray,
-                  parang: Optional[np.ndarray],
-                  cube_mean: np.ndarray) -> Tuple[np.array, Optional[np.ndarray], np.ndarray,
-                                                  np.ndarray, Optional[np.ndarray], np.ndarray]:
+    def _separate(
+        self,
+        bg_frames: np.ndarray,
+        bg_indices: np.ndarray,
+        parang: Optional[np.ndarray],
+        cube_mean: np.ndarray,
+    ) -> Tuple[
+        np.array,
+        Optional[np.ndarray],
+        np.ndarray,
+        np.ndarray,
+        Optional[np.ndarray],
+        np.ndarray,
+    ]:
 
         @typechecked
-        def _initialize() -> Tuple[np.array, Optional[np.ndarray], np.ndarray, np.ndarray,
-                                   Optional[np.ndarray], np.ndarray]:
+        def _initialize() -> Tuple[
+            np.array,
+            Optional[np.ndarray],
+            np.ndarray,
+            np.ndarray,
+            Optional[np.ndarray],
+            np.ndarray,
+        ]:
 
             background_nframes = np.empty(0, dtype=np.int64)
             star_nframes = np.empty(0, dtype=np.int64)
@@ -148,8 +174,14 @@ class PCABackgroundPreparationModule(ProcessingModule):
                 background_parang = np.empty(0, dtype=np.float64)
                 star_parang = np.empty(0, dtype=np.float64)
 
-            return star_index, star_parang, star_nframes, background_index, \
-                background_parang, background_nframes
+            return (
+                star_index,
+                star_parang,
+                star_nframes,
+                background_index,
+                background_parang,
+                background_nframes,
+            )
 
         @typechecked
         def _select_background(i: int) -> np.ndarray:
@@ -157,7 +189,7 @@ class PCABackgroundPreparationModule(ProcessingModule):
             # Previous background cube
             if np.size(bg_indices[bg_indices < i]) > 0:
                 index_prev = np.amax(bg_indices[bg_indices < i])
-                bg_prev = cube_mean[index_prev, ]
+                bg_prev = cube_mean[index_prev,]
 
             else:
                 bg_prev = None
@@ -165,7 +197,7 @@ class PCABackgroundPreparationModule(ProcessingModule):
             # Next background cube
             if np.size(bg_indices[bg_indices > i]) > 0:
                 index_next = np.amin(bg_indices[bg_indices > i])
-                bg_next = cube_mean[index_next, ]
+                bg_next = cube_mean[index_next,]
 
             else:
                 bg_next = None
@@ -178,27 +210,37 @@ class PCABackgroundPreparationModule(ProcessingModule):
                 background = bg_prev
 
             elif bg_prev is not None and bg_next is not None:
-                background = (bg_prev+bg_next)/2.
+                background = (bg_prev + bg_next) / 2.0
 
             else:
-                raise ValueError('Neither previous nor next background frames are found.')
+                raise ValueError(
+                    "Neither previous nor next background frames are found."
+                )
 
             return background
 
-        nframes = self.m_image_in_port.get_attribute('NFRAMES')
-        index = self.m_image_in_port.get_attribute('INDEX')
+        nframes = self.m_image_in_port.get_attribute("NFRAMES")
+        index = self.m_image_in_port.get_attribute("INDEX")
 
-        star_index, star_parang, star_nframes, background_index, background_parang, \
-            background_nframes = _initialize()
+        (
+            star_index,
+            star_parang,
+            star_nframes,
+            background_index,
+            background_parang,
+            background_nframes,
+        ) = _initialize()
 
         # Separate star and background cubes. Subtract mean background.
         count = 0
 
         start_time = time.time()
         for i, item in enumerate(nframes):
-            progress(i, len(nframes), 'Preparing PCA background subtraction...', start_time)
+            progress(
+                i, len(nframes), "Preparing PCA background subtraction...", start_time
+            )
 
-            im_tmp = self.m_image_in_port[count:count+item, ]
+            im_tmp = self.m_image_in_port[count : count + item,]
 
             # Background frames
             if bg_frames[i]:
@@ -206,28 +248,38 @@ class PCABackgroundPreparationModule(ProcessingModule):
                 self.m_background_out_port.append(im_tmp)
 
                 background_nframes = np.append(background_nframes, nframes[i])
-                background_index = np.append(background_index, index[count:count+item])
+                background_index = np.append(
+                    background_index, index[count : count + item]
+                )
 
                 if parang is not None:
-                    background_parang = np.append(background_parang, parang[count:count+item])
+                    background_parang = np.append(
+                        background_parang, parang[count : count + item]
+                    )
 
             # Star frames
             else:
                 background = _select_background(i)
 
                 self.m_star_out_port.append(im_tmp)
-                self.m_subtracted_out_port.append(im_tmp-background)
+                self.m_subtracted_out_port.append(im_tmp - background)
 
                 star_nframes = np.append(star_nframes, nframes[i])
-                star_index = np.append(star_index, index[count:count+item])
+                star_index = np.append(star_index, index[count : count + item])
 
                 if parang is not None:
-                    star_parang = np.append(star_parang, parang[count:count+item])
+                    star_parang = np.append(star_parang, parang[count : count + item])
 
             count += item
 
-        return star_index, star_parang, star_nframes, background_index, \
-            background_parang, background_nframes
+        return (
+            star_index,
+            star_parang,
+            star_nframes,
+            background_index,
+            background_parang,
+            background_nframes,
+        )
 
     @typechecked
     def run(self) -> None:
@@ -242,8 +294,8 @@ class PCABackgroundPreparationModule(ProcessingModule):
             None
         """
 
-        if 'PARANG' in self.m_image_in_port.get_all_non_static_attributes():
-            parang = self.m_image_in_port.get_attribute('PARANG')
+        if "PARANG" in self.m_image_in_port.get_all_non_static_attributes():
+            parang = self.m_image_in_port.get_attribute("PARANG")
         else:
             parang = None
 
@@ -251,34 +303,52 @@ class PCABackgroundPreparationModule(ProcessingModule):
 
         bg_indices = np.nonzero(bg_frames)[0]
 
-        star_index, star_parang, star_nframes, background_index, background_parang, \
-            background_nframes = self._separate(bg_frames, bg_indices, parang, cube_mean)
+        (
+            star_index,
+            star_parang,
+            star_nframes,
+            background_index,
+            background_parang,
+            background_nframes,
+        ) = self._separate(bg_frames, bg_indices, parang, cube_mean)
 
-        history = f'frames = {sum(star_nframes)}, {len(background_nframes)}'
+        history = f"frames = {sum(star_nframes)}, {len(background_nframes)}"
 
         self.m_star_out_port.copy_attributes(self.m_image_in_port)
-        self.m_star_out_port.add_history('PCABackgroundPreparationModule', history)
-        self.m_star_out_port.add_attribute('NFRAMES', star_nframes, static=False)
-        self.m_star_out_port.add_attribute('INDEX', star_index, static=False)
+        self.m_star_out_port.add_history("PCABackgroundPreparationModule", history)
+        self.m_star_out_port.add_attribute("NFRAMES", star_nframes, static=False)
+        self.m_star_out_port.add_attribute("INDEX", star_index, static=False)
 
         if parang is not None:
-            self.m_star_out_port.add_attribute('PARANG', star_parang, static=False)
+            self.m_star_out_port.add_attribute("PARANG", star_parang, static=False)
 
         self.m_subtracted_out_port.copy_attributes(self.m_image_in_port)
-        self.m_subtracted_out_port.add_history('PCABackgroundPreparationModule', history)
-        self.m_subtracted_out_port.add_attribute('NFRAMES', star_nframes, static=False)
-        self.m_subtracted_out_port.add_attribute('INDEX', star_index, static=False)
+        self.m_subtracted_out_port.add_history(
+            "PCABackgroundPreparationModule", history
+        )
+        self.m_subtracted_out_port.add_attribute("NFRAMES", star_nframes, static=False)
+        self.m_subtracted_out_port.add_attribute("INDEX", star_index, static=False)
 
         if parang is not None:
-            self.m_subtracted_out_port.add_attribute('PARANG', star_parang, static=False)
+            self.m_subtracted_out_port.add_attribute(
+                "PARANG", star_parang, static=False
+            )
 
         self.m_background_out_port.copy_attributes(self.m_image_in_port)
-        self.m_background_out_port.add_history('PCABackgroundPreparationModule', history)
-        self.m_background_out_port.add_attribute('NFRAMES', background_nframes, static=False)
-        self.m_background_out_port.add_attribute('INDEX', background_index, static=False)
+        self.m_background_out_port.add_history(
+            "PCABackgroundPreparationModule", history
+        )
+        self.m_background_out_port.add_attribute(
+            "NFRAMES", background_nframes, static=False
+        )
+        self.m_background_out_port.add_attribute(
+            "INDEX", background_index, static=False
+        )
 
         if parang is not None:
-            self.m_background_out_port.add_attribute('PARANG', background_parang, static=False)
+            self.m_background_out_port.add_attribute(
+                "PARANG", background_parang, static=False
+            )
 
         self.m_star_out_port.close_port()
 
@@ -288,21 +358,23 @@ class PCABackgroundSubtractionModule(ProcessingModule):
     Pipeline module applying a PCA-based background subtraction (see Hunziker et al. 2018).
     """
 
-    __author__ = 'Tomas Stolker, Silvan Hunziker'
+    __author__ = "Tomas Stolker, Silvan Hunziker"
 
     @typechecked
-    def __init__(self,
-                 name_in: str,
-                 star_in_tag: str,
-                 background_in_tag: str,
-                 residuals_out_tag: str,
-                 fit_out_tag: Optional[str] = None,
-                 mask_out_tag: Optional[str] = None,
-                 pca_number: int = 60,
-                 mask_star: float = 0.7,
-                 subframe: Optional[float] = None,
-                 gaussian: float = 0.15,
-                 **kwargs) -> None:
+    def __init__(
+        self,
+        name_in: str,
+        star_in_tag: str,
+        background_in_tag: str,
+        residuals_out_tag: str,
+        fit_out_tag: Optional[str] = None,
+        mask_out_tag: Optional[str] = None,
+        pca_number: int = 60,
+        mask_star: float = 0.7,
+        subframe: Optional[float] = None,
+        gaussian: float = 0.15,
+        **kwargs,
+    ) -> None:
         """
         Parameters
         ----------
@@ -338,10 +410,12 @@ class PCABackgroundSubtractionModule(ProcessingModule):
 
         super().__init__(name_in)
 
-        if 'subtract_mean' in kwargs:
-            warnings.warn('The \'subtract_mean\' parameter has been deprecated. Subtracting of '
-                          'the mean is no longer optional so subtract_mean=True.',
-                          DeprecationWarning)
+        if "subtract_mean" in kwargs:
+            warnings.warn(
+                "The 'subtract_mean' parameter has been deprecated. Subtracting of "
+                "the mean is no longer optional so subtract_mean=True.",
+                DeprecationWarning,
+            )
 
         self.m_star_in_port = self.add_input_port(star_in_tag)
         self.m_background_in_port = self.add_input_port(background_in_tag)
@@ -377,9 +451,9 @@ class PCABackgroundSubtractionModule(ProcessingModule):
         """
 
         @typechecked
-        def _create_mask(radius: float,
-                         position: np.ndarray,
-                         nimages: int) -> np.ndarray:
+        def _create_mask(
+            radius: float, position: np.ndarray, nimages: int
+        ) -> np.ndarray:
             """
             Method for creating a circular mask at the star or planet position.
             """
@@ -397,14 +471,15 @@ class PCABackgroundSubtractionModule(ProcessingModule):
             cent_y = position[:, 0]
 
             for i in range(nimages):
-                rr_grid = np.sqrt((xx_grid - cent_x[i])**2 + (yy_grid - cent_y[i])**2)
-                mask[i, ][rr_grid < radius] = 0.
+                rr_grid = np.sqrt(
+                    (xx_grid - cent_x[i]) ** 2 + (yy_grid - cent_y[i]) ** 2
+                )
+                mask[i,][rr_grid < radius] = 0.0
 
             return mask
 
         @typechecked
-        def _create_basis(images: np.ndarray,
-                          pca_number: int) -> np.ndarray:
+        def _create_basis(images: np.ndarray, pca_number: int) -> np.ndarray:
             """
             Method for calculating the principal components for a stack of background images.
 
@@ -421,25 +496,25 @@ class PCABackgroundSubtractionModule(ProcessingModule):
                 Principal components with the second and third dimension reshaped to ``images``.
             """
 
-            _, _, v_svd = svds(images.reshape(images.shape[0],
-                                              images.shape[1]*images.shape[2]),
-                               k=pca_number)
+            _, _, v_svd = svds(
+                images.reshape(images.shape[0], images.shape[1] * images.shape[2]),
+                k=pca_number,
+            )
 
-            v_svd = v_svd[::-1, ]
+            v_svd = v_svd[::-1,]
 
             return v_svd.reshape(v_svd.shape[0], images.shape[1], images.shape[2])
 
         @typechecked
-        def _model_background(basis: np.ndarray,
-                              im_arr: np.ndarray,
-                              mask: np.ndarray) -> np.ndarray:
+        def _model_background(
+            basis: np.ndarray, im_arr: np.ndarray, mask: np.ndarray
+        ) -> np.ndarray:
             """
             Method for creating a model of the background.
             """
 
             @typechecked
-            def _dot_product(x_dot: np.ndarray,
-                             *p: np.float64) -> np.ndarray:
+            def _dot_product(x_dot: np.ndarray, *p: np.float64) -> np.ndarray:
                 return np.dot(p, x_dot)
 
             fit_im_chi = np.zeros(im_arr.shape)
@@ -448,33 +523,32 @@ class PCABackgroundSubtractionModule(ProcessingModule):
             basis_reshaped = basis.reshape(basis.shape[0], -1)
 
             for i in range(im_arr.shape[0]):
-                basis_reshaped_masked = (basis*mask[i]).reshape(basis.shape[0], -1)
+                basis_reshaped_masked = (basis * mask[i]).reshape(basis.shape[0], -1)
 
-                data_to_fit = im_arr[i, ]
+                data_to_fit = im_arr[i,]
 
                 init = np.ones(basis_reshaped_masked.shape[0])
 
-                fitted = curve_fit(_dot_product,
-                                   basis_reshaped_masked,
-                                   data_to_fit.reshape(-1),
-                                   init)
+                fitted = curve_fit(
+                    _dot_product, basis_reshaped_masked, data_to_fit.reshape(-1), init
+                )
 
                 fit_im = np.dot(fitted[0], basis_reshaped)
                 fit_im = fit_im.reshape(data_to_fit.shape[0], data_to_fit.shape[1])
 
-                fit_im_chi[i, ] = fit_im
+                fit_im_chi[i,] = fit_im
                 # fit_coeff_chi[i, ] = fitted[0]
 
             return fit_im_chi
 
-        memory = self._m_config_port.get_attribute('MEMORY')
-        pixscale = self.m_star_in_port.get_attribute('PIXSCALE')
+        memory = self._m_config_port.get_attribute("MEMORY")
+        pixscale = self.m_star_in_port.get_attribute("PIXSCALE")
 
         nimages = self.m_star_in_port.get_shape()[0]
         frames = memory_frames(memory, nimages)
 
         self.m_mask_star /= pixscale
-        self.m_gaussian = int(math.ceil(self.m_gaussian/pixscale))
+        self.m_gaussian = int(math.ceil(self.m_gaussian / pixscale))
 
         if self.m_subframe is not None:
             self.m_subframe /= pixscale
@@ -484,32 +558,37 @@ class PCABackgroundSubtractionModule(ProcessingModule):
 
         star = np.zeros((nimages, 2))
         for i, _ in enumerate(star):
-            star[i, :] = locate_star(image=self.m_star_in_port[i, ] - bg_mean,
-                                     center=None,
-                                     width=self.m_subframe,
-                                     fwhm=self.m_gaussian)
+            star[i, :] = locate_star(
+                image=self.m_star_in_port[i,] - bg_mean,
+                center=None,
+                width=self.m_subframe,
+                fwhm=self.m_gaussian,
+            )
 
-        print('Creating PCA basis set...', end='')
+        print("Creating PCA basis set...", end="")
 
-        basis_pca = _create_basis(self.m_background_in_port.get_all() - bg_mean,
-                                  self.m_pca_number)
+        basis_pca = _create_basis(
+            self.m_background_in_port.get_all() - bg_mean, self.m_pca_number
+        )
 
-        print(' [DONE]')
+        print(" [DONE]")
 
         start_time = time.time()
         for i, _ in enumerate(frames[:-1]):
-            progress(i, len(frames[:-1]), 'Calculating background model...', start_time)
+            progress(i, len(frames[:-1]), "Calculating background model...", start_time)
 
             # Subtract the mean background from the star frames
-            im_star = self.m_star_in_port[frames[i]:frames[i+1], ] - bg_mean
+            im_star = self.m_star_in_port[frames[i] : frames[i + 1],] - bg_mean
 
-            mask = _create_mask(self.m_mask_star,
-                                star[frames[i]:frames[i+1], ],
-                                int(frames[i+1]-frames[i]))
+            mask = _create_mask(
+                self.m_mask_star,
+                star[frames[i] : frames[i + 1],],
+                int(frames[i + 1] - frames[i]),
+            )
 
-            fit_im = _model_background(basis_pca, im_star*mask, mask)
+            fit_im = _model_background(basis_pca, im_star * mask, mask)
 
-            self.m_residuals_out_port.append(im_star-fit_im)
+            self.m_residuals_out_port.append(im_star - fit_im)
 
             if self.m_fit_out_port is not None:
                 self.m_fit_out_port.append(fit_im)
@@ -517,18 +596,18 @@ class PCABackgroundSubtractionModule(ProcessingModule):
             if self.m_mask_out_port is not None:
                 self.m_mask_out_port.append(mask)
 
-        history = f'PC number = {self.m_pca_number}'
+        history = f"PC number = {self.m_pca_number}"
         self.m_residuals_out_port.copy_attributes(self.m_star_in_port)
-        self.m_residuals_out_port.add_history('PCABackgroundSubtractionModule', history)
-        self.m_residuals_out_port.add_attribute('STAR_POSITION', star, static=False)
+        self.m_residuals_out_port.add_history("PCABackgroundSubtractionModule", history)
+        self.m_residuals_out_port.add_attribute("STAR_POSITION", star, static=False)
 
         if self.m_fit_out_port is not None:
             self.m_fit_out_port.copy_attributes(self.m_star_in_port)
-            self.m_fit_out_port.add_history('PCABackgroundSubtractionModule', history)
+            self.m_fit_out_port.add_history("PCABackgroundSubtractionModule", history)
 
         if self.m_mask_out_port is not None:
             self.m_mask_out_port.copy_attributes(self.m_star_in_port)
-            self.m_mask_out_port.add_history('PCABackgroundSubtractionModule', history)
+            self.m_mask_out_port.add_history("PCABackgroundSubtractionModule", history)
 
         self.m_residuals_out_port.close_port()
 
@@ -539,21 +618,23 @@ class DitheringBackgroundModule(ProcessingModule):
     applies the processing modules for either a mean or the PCA-based background subtraction.
     """
 
-    __author__ = 'Tomas Stolker'
+    __author__ = "Tomas Stolker"
 
     @typechecked
-    def __init__(self,
-                 name_in: str,
-                 image_in_tag: str,
-                 image_out_tag: str,
-                 center: Optional[List[Tuple[int, int]]] = None,
-                 cubes: Optional[int] = None,
-                 size: float = 2.,
-                 gaussian: float = 0.15,
-                 subframe: Optional[float] = None,
-                 pca_number: Optional[int] = 5,
-                 mask_star: float = 0.7,
-                 **kwargs) -> None:
+    def __init__(
+        self,
+        name_in: str,
+        image_in_tag: str,
+        image_out_tag: str,
+        center: Optional[List[Tuple[int, int]]] = None,
+        cubes: Optional[int] = None,
+        size: float = 2.0,
+        gaussian: float = 0.15,
+        subframe: Optional[float] = None,
+        pca_number: Optional[int] = 5,
+        mask_star: float = 0.7,
+        **kwargs,
+    ) -> None:
         """
         Parameters
         ----------
@@ -599,31 +680,47 @@ class DitheringBackgroundModule(ProcessingModule):
             None
         """
 
-        if 'mask_planet' in kwargs:
-            warnings.warn('The \'mask_planet\' parameter has been deprecated.', DeprecationWarning)
+        if "mask_planet" in kwargs:
+            warnings.warn(
+                "The 'mask_planet' parameter has been deprecated.", DeprecationWarning
+            )
 
-        if 'crop' in kwargs:
-            warnings.warn('The \'crop\' parameter has been deprecated. The step to crop the '
-                          'images is no longer optional so crop=True.', DeprecationWarning)
+        if "crop" in kwargs:
+            warnings.warn(
+                "The 'crop' parameter has been deprecated. The step to crop the "
+                "images is no longer optional so crop=True.",
+                DeprecationWarning,
+            )
 
-        if 'prepare' in kwargs:
-            warnings.warn('The \'prepare\' parameter has been deprecated. The preparation step '
-                          'is no longer optional so prepare=True.', DeprecationWarning)
+        if "prepare" in kwargs:
+            warnings.warn(
+                "The 'prepare' parameter has been deprecated. The preparation step "
+                "is no longer optional so prepare=True.",
+                DeprecationWarning,
+            )
 
-        if 'pca_background' in kwargs:
-            warnings.warn('The \'pca_background\' parameter has been deprecated. The PCA '
-                          'background is no longer optional when combine=\'pca\' so '
-                          'pca_background=True.', DeprecationWarning)
+        if "pca_background" in kwargs:
+            warnings.warn(
+                "The 'pca_background' parameter has been deprecated. The PCA "
+                "background is no longer optional when combine='pca' so "
+                "pca_background=True.",
+                DeprecationWarning,
+            )
 
-        if 'subtract_mean' in kwargs:
-            warnings.warn('The \'subtract_mean\' parameter has been deprecated. Subtracting of '
-                          'the mean is no longer optional so subtract_mean=True.',
-                          DeprecationWarning)
+        if "subtract_mean" in kwargs:
+            warnings.warn(
+                "The 'subtract_mean' parameter has been deprecated. Subtracting of "
+                "the mean is no longer optional so subtract_mean=True.",
+                DeprecationWarning,
+            )
 
-        if 'combine' in kwargs:
-            warnings.warn('The \'combine\' parameter has been deprecated. To write the mean '
-                          'background subtracted images to image_out_tag is done by setting '
-                          'pca_number=None.', DeprecationWarning)
+        if "combine" in kwargs:
+            warnings.warn(
+                "The 'combine' parameter has been deprecated. To write the mean "
+                "background subtracted images to image_out_tag is done by setting "
+                "pca_number=None.",
+                DeprecationWarning,
+            )
 
         super().__init__(name_in)
 
@@ -644,8 +741,8 @@ class DitheringBackgroundModule(ProcessingModule):
     @typechecked
     def _initialize(self) -> Tuple[int, np.ndarray]:
         if self.m_cubes is None:
-            dither_x = self.m_image_in_port.get_attribute('DITHER_X')
-            dither_y = self.m_image_in_port.get_attribute('DITHER_Y')
+            dither_x = self.m_image_in_port.get_attribute("DITHER_X")
+            dither_y = self.m_image_in_port.get_attribute("DITHER_Y")
 
             dither_xy = np.zeros((dither_x.shape[0], 2))
             dither_xy[:, 0] = dither_x
@@ -659,15 +756,18 @@ class DitheringBackgroundModule(ProcessingModule):
 
             # Compute center from dither and make sure all positions are actually Python integers
             if self.m_center is None:
-                self.m_center = np.copy(dither) + float(npix) / 2.
+                self.m_center = np.copy(dither) + float(npix) / 2.0
 
-                self.m_center = tuple(zip(map(int, self.m_center[:, 0]),
-                                          map(int, self.m_center[:, 1])))
+                self.m_center = tuple(
+                    zip(map(int, self.m_center[:, 0]), map(int, self.m_center[:, 1]))
+                )
 
             else:
                 if np.size(dither, axis=0) != np.size(self.m_center, axis=0):
-                    raise ValueError('Number of specified center positions should be equal to the '
-                                     'number of unique dithering positions.')
+                    raise ValueError(
+                        "Number of specified center positions should be equal to the "
+                        "number of unique dithering positions."
+                    )
 
         n_dither = np.size(self.m_center, 0)
 
@@ -693,23 +793,25 @@ class DitheringBackgroundModule(ProcessingModule):
         """
 
         @typechecked
-        def _admin_start(count: int,
-                         n_dither: int,
-                         position: Tuple[int, int],
-                         star_pos: Union[np.ndarray, np.int64]) -> None:
-            print(f'Processing dither position {count+1} out of {n_dither}...')
-            print(f'Center position = {position}')
+        def _admin_start(
+            count: int,
+            n_dither: int,
+            position: Tuple[int, int],
+            star_pos: Union[np.ndarray, np.int64],
+        ) -> None:
+            print(f"Processing dither position {count+1} out of {n_dither}...")
+            print(f"Center position = {position}")
 
             if self.m_cubes is None and self.m_center is not None:
-                print(f'DITHER_X, DITHER_Y = {tuple(star_pos)}')
+                print(f"DITHER_X, DITHER_Y = {tuple(star_pos)}")
 
         @typechecked
         def _admin_end(count: int) -> None:
             if self.m_pca_number is None:
-                tags.append(f'{self.m_image_in_tag}_dither_mean{count+1}')
+                tags.append(f"{self.m_image_in_tag}_dither_mean{count+1}")
 
             else:
-                tags.append(f'{self.m_image_in_tag}_dither_pca_res{count+1}')
+                tags.append(f"{self.m_image_in_tag}_dither_pca_res{count+1}")
 
         n_dither, star_pos = self._initialize()
         tags = []
@@ -717,14 +819,15 @@ class DitheringBackgroundModule(ProcessingModule):
         for i, position in enumerate(self.m_center):
             _admin_start(i, n_dither, position, star_pos[i])
 
-            im_out_tag = f'{self.m_image_in_tag}_dither_crop{i+1}'
+            im_out_tag = f"{self.m_image_in_tag}_dither_crop{i+1}"
 
-            module = CropImagesModule(name_in=f'crop{i}',
-                                      image_in_tag=self.m_image_in_tag,
-                                      image_out_tag=im_out_tag,
-                                      size=self.m_size,
-                                      center=(int(math.ceil(position[0])),
-                                              int(math.ceil(position[1]))))
+            module = CropImagesModule(
+                name_in=f"crop{i}",
+                image_in_tag=self.m_image_in_tag,
+                image_out_tag=im_out_tag,
+                size=self.m_size,
+                center=(int(math.ceil(position[0])), int(math.ceil(position[1]))),
+            )
 
             module.connect_database(self._m_data_base)
             module._m_output_ports[im_out_tag].del_all_data()
@@ -736,18 +839,20 @@ class DitheringBackgroundModule(ProcessingModule):
             else:
                 dither_val = (n_dither, self.m_cubes, int(star_pos[i]))
 
-            im_in_tag = f'{self.m_image_in_tag}_dither_crop{i+1}'
-            star_out_tag = f'{self.m_image_in_tag}_dither_star{i+1}'
-            sub_out_tag = f'{self.m_image_in_tag}_dither_mean{i+1}'
-            back_out_tag = f'{self.m_image_in_tag}_dither_background{i+1}'
+            im_in_tag = f"{self.m_image_in_tag}_dither_crop{i+1}"
+            star_out_tag = f"{self.m_image_in_tag}_dither_star{i+1}"
+            sub_out_tag = f"{self.m_image_in_tag}_dither_mean{i+1}"
+            back_out_tag = f"{self.m_image_in_tag}_dither_background{i+1}"
 
-            module = PCABackgroundPreparationModule(name_in=f'prepare{i}',
-                                                    image_in_tag=im_in_tag,
-                                                    star_out_tag=star_out_tag,
-                                                    subtracted_out_tag=sub_out_tag,
-                                                    background_out_tag=back_out_tag,
-                                                    dither=dither_val,
-                                                    combine='mean')
+            module = PCABackgroundPreparationModule(
+                name_in=f"prepare{i}",
+                image_in_tag=im_in_tag,
+                star_out_tag=star_out_tag,
+                subtracted_out_tag=sub_out_tag,
+                background_out_tag=back_out_tag,
+                dither=dither_val,
+                combine="mean",
+            )
 
             module.connect_database(self._m_data_base)
             module._m_output_ports[star_out_tag].del_all_data()
@@ -759,22 +864,24 @@ class DitheringBackgroundModule(ProcessingModule):
             module.run()
 
             if self.m_pca_number is not None:
-                star_in_tag = f'{self.m_image_in_tag}_dither_star{i+1}'
-                back_in_tag = f'{self.m_image_in_tag}_dither_background{i+1}'
-                res_out_tag = f'{self.m_image_in_tag}_dither_pca_res{i+1}'
-                fit_out_tag = f'{self.m_image_in_tag}_dither_pca_fit{i+1}'
-                mask_out_tag = f'{self.m_image_in_tag}_dither_pca_mask{i+1}'
+                star_in_tag = f"{self.m_image_in_tag}_dither_star{i+1}"
+                back_in_tag = f"{self.m_image_in_tag}_dither_background{i+1}"
+                res_out_tag = f"{self.m_image_in_tag}_dither_pca_res{i+1}"
+                fit_out_tag = f"{self.m_image_in_tag}_dither_pca_fit{i+1}"
+                mask_out_tag = f"{self.m_image_in_tag}_dither_pca_mask{i+1}"
 
-                module = PCABackgroundSubtractionModule(name_in=f'pca_background{i}',
-                                                        star_in_tag=star_in_tag,
-                                                        background_in_tag=back_in_tag,
-                                                        residuals_out_tag=res_out_tag,
-                                                        fit_out_tag=fit_out_tag,
-                                                        mask_out_tag=mask_out_tag,
-                                                        pca_number=self.m_pca_number,
-                                                        mask_star=self.m_mask_star,
-                                                        subframe=self.m_subframe,
-                                                        gaussian=self.m_gaussian)
+                module = PCABackgroundSubtractionModule(
+                    name_in=f"pca_background{i}",
+                    star_in_tag=star_in_tag,
+                    background_in_tag=back_in_tag,
+                    residuals_out_tag=res_out_tag,
+                    fit_out_tag=fit_out_tag,
+                    mask_out_tag=mask_out_tag,
+                    pca_number=self.m_pca_number,
+                    mask_star=self.m_mask_star,
+                    subframe=self.m_subframe,
+                    gaussian=self.m_gaussian,
+                )
 
                 module.connect_database(self._m_data_base)
                 module._m_output_ports[res_out_tag].del_all_data()
@@ -787,20 +894,26 @@ class DitheringBackgroundModule(ProcessingModule):
 
             _admin_end(i)
 
-        module = CombineTagsModule(name_in='combine',
-                                   check_attr=True,
-                                   index_init=False,
-                                   image_in_tags=tags,
-                                   image_out_tag=self.m_image_in_tag+'_dither_combine')
+        module = CombineTagsModule(
+            name_in="combine",
+            check_attr=True,
+            index_init=False,
+            image_in_tags=tags,
+            image_out_tag=self.m_image_in_tag + "_dither_combine",
+        )
 
         module.connect_database(self._m_data_base)
-        module._m_output_ports[self.m_image_in_tag+'_dither_combine'].del_all_data()
-        module._m_output_ports[self.m_image_in_tag+'_dither_combine'].del_all_attributes()
+        module._m_output_ports[self.m_image_in_tag + "_dither_combine"].del_all_data()
+        module._m_output_ports[
+            self.m_image_in_tag + "_dither_combine"
+        ].del_all_attributes()
         module.run()
 
-        module = SortParangModule(name_in='sort',
-                                  image_in_tag=self.m_image_in_tag+'_dither_combine',
-                                  image_out_tag=self.m_image_out_tag)
+        module = SortParangModule(
+            name_in="sort",
+            image_in_tag=self.m_image_in_tag + "_dither_combine",
+            image_out_tag=self.m_image_out_tag,
+        )
 
         module.connect_database(self._m_data_base)
         module._m_output_ports[self.m_image_out_tag].del_all_data()
