@@ -22,14 +22,16 @@ class StackAndSubsetModule(ProcessingModule):
     """
 
     @typechecked
-    def __init__(self,
-                 name_in: str,
-                 image_in_tag: str,
-                 image_out_tag: str,
-                 random: Optional[int] = None,
-                 stacking: Optional[int] = None,
-                 combine: str = 'mean',
-                 max_rotation: Optional[float] = None) -> None:
+    def __init__(
+        self,
+        name_in: str,
+        image_in_tag: str,
+        image_out_tag: str,
+        random: Optional[int] = None,
+        stacking: Optional[int] = None,
+        combine: str = "mean",
+        max_rotation: Optional[float] = None,
+    ) -> None:
         """
         Parameters
         ----------
@@ -68,7 +70,7 @@ class StackAndSubsetModule(ProcessingModule):
         self.m_max_rotation = max_rotation
 
         if self.m_stacking is None and self.m_random is None:
-            warnings.warn('Both \'stacking\' and \'random\' are set to None.')
+            warnings.warn("Both 'stacking' and 'random' are set to None.")
 
     @typechecked
     def run(self) -> None:
@@ -83,9 +85,9 @@ class StackAndSubsetModule(ProcessingModule):
         """
 
         @typechecked
-        def _stack_subsets(nimages: int,
-                           im_shape: Tuple[int, ...],
-                           parang: np.ndarray) -> Tuple[Tuple[int, ...], np.ndarray, np.ndarray]:
+        def _stack_subsets(
+            nimages: int, im_shape: Tuple[int, ...], parang: Optional[np.ndarray]
+        ) -> Tuple[Tuple[int, ...], np.ndarray, Optional[np.ndarray]]:
 
             im_new = None
             parang_new = None
@@ -96,7 +98,7 @@ class StackAndSubsetModule(ProcessingModule):
                 else:
                     frames = memory_frames(self.m_stacking, nimages)
 
-                nimages_new = np.size(frames)-1
+                nimages_new = np.size(frames) - 1
 
                 if parang is None:
                     parang_new = None
@@ -108,18 +110,20 @@ class StackAndSubsetModule(ProcessingModule):
                 start_time = time.time()
 
                 for i in range(nimages_new):
-                    progress(i, nimages_new, 'Stacking subsets of images...', start_time)
+                    progress(
+                        i, nimages_new, "Stacking subsets of images...", start_time
+                    )
 
                     if parang is not None:
                         # parang_new[i] = np.mean(parang[frames[i]:frames[i+1]])
-                        parang_new[i] = angle_average(parang[frames[i]:frames[i+1]])
+                        parang_new[i] = angle_average(parang[frames[i] : frames[i + 1]])
 
-                    im_subset = self.m_image_in_port[frames[i]:frames[i+1], ]
+                    im_subset = self.m_image_in_port[frames[i] : frames[i + 1],]
 
-                    if self.m_combine == 'mean':
-                        im_new[i, ] = np.mean(im_subset, axis=0)
-                    elif self.m_combine == 'median':
-                        im_new[i, ] = np.median(im_subset, axis=0)
+                    if self.m_combine == "mean":
+                        im_new[i,] = np.mean(im_subset, axis=0)
+                    elif self.m_combine == "median":
+                        im_new[i,] = np.median(im_subset, axis=0)
 
                 im_shape = im_new.shape
 
@@ -130,9 +134,9 @@ class StackAndSubsetModule(ProcessingModule):
             return im_shape, im_new, parang_new
 
         @typechecked
-        def _random_subset(im_shape: Tuple[int, ...],
-                           im_new: np.ndarray,
-                           parang_new: np.ndarray) -> Tuple[int, np.ndarray, np.ndarray]:
+        def _random_subset(
+            im_shape: Tuple[int, ...], im_new: np.ndarray, parang_new: Optional[np.ndarray]
+        ) -> Tuple[int, np.ndarray, Optional[np.ndarray]]:
 
             if self.m_random is not None:
                 choice = np.random.choice(im_shape[0], self.m_random, replace=False)
@@ -144,9 +148,9 @@ class StackAndSubsetModule(ProcessingModule):
                     parang_new = parang_new[choice]
 
                 if self.m_stacking is None:
-                    im_new = self.m_image_in_port[list(choice), ]
+                    im_new = self.m_image_in_port[list(choice),]
                 else:
-                    im_new = im_new[choice, ]
+                    im_new = im_new[choice,]
 
             if self.m_random is None and self.m_stacking is None:
                 nimages = 0
@@ -164,16 +168,22 @@ class StackAndSubsetModule(ProcessingModule):
 
         if self.m_random is not None:
             if self.m_stacking is None and im_shape[0] < self.m_random:
-                raise ValueError('The number of images of the destination subset is larger than '
-                                 'the number of images in the source.')
+                raise ValueError(
+                    "The number of images of the destination subset is larger than "
+                    "the number of images in the source."
+                )
 
-            if self.m_stacking is not None and \
-                    int(float(im_shape[0])/float(self.m_stacking)) < self.m_random:
-                raise ValueError('The number of images of the destination subset is larger than '
-                                 'the number of images in the stacked source.')
+            if (
+                self.m_stacking is not None
+                and int(float(im_shape[0]) / float(self.m_stacking)) < self.m_random
+            ):
+                raise ValueError(
+                    "The number of images of the destination subset is larger than "
+                    "the number of images in the stacked source."
+                )
 
-        if 'PARANG' in non_static:
-            parang = self.m_image_in_port.get_attribute('PARANG')
+        if "PARANG" in non_static:
+            parang = self.m_image_in_port.get_attribute("PARANG")
         else:
             parang = None
 
@@ -183,16 +193,18 @@ class StackAndSubsetModule(ProcessingModule):
         if self.m_random or self.m_stacking:
             self.m_image_out_port.set_all(im_new, keep_attributes=True)
             self.m_image_out_port.copy_attributes(self.m_image_in_port)
-            self.m_image_out_port.add_attribute('INDEX', np.arange(0, nimages, 1), static=False)
+            self.m_image_out_port.add_attribute(
+                "INDEX", np.arange(0, nimages, 1), static=False
+            )
 
             if parang_new is not None:
-                self.m_image_out_port.add_attribute('PARANG', parang_new, static=False)
+                self.m_image_out_port.add_attribute("PARANG", parang_new, static=False)
 
-            if 'NFRAMES' in non_static:
-                self.m_image_out_port.del_attribute('NFRAMES')
+            if "NFRAMES" in non_static:
+                self.m_image_out_port.del_attribute("NFRAMES")
 
-            history = f'stacking = {self.m_stacking}, random = {self.m_random}'
-            self.m_image_out_port.add_history('StackAndSubsetModule', history)
+            history = f"stacking = {self.m_stacking}, random = {self.m_random}"
+            self.m_image_out_port.add_history("StackAndSubsetModule", history)
 
         self.m_image_out_port.close_port()
 
@@ -204,11 +216,9 @@ class StackCubesModule(ProcessingModule):
     """
 
     @typechecked
-    def __init__(self,
-                 name_in: str,
-                 image_in_tag: str,
-                 image_out_tag: str,
-                 combine: str = 'mean') -> None:
+    def __init__(
+        self, name_in: str, image_in_tag: str, image_out_tag: str, combine: str = "mean"
+    ) -> None:
         """
         Parameters
         ----------
@@ -248,13 +258,13 @@ class StackCubesModule(ProcessingModule):
         """
 
         if self.m_image_in_port.tag == self.m_image_out_port.tag:
-            raise ValueError('Input and output port should have a different tag.')
+            raise ValueError("Input and output port should have a different tag.")
 
         non_static = self.m_image_in_port.get_all_non_static_attributes()
-        nframes = self.m_image_in_port.get_attribute('NFRAMES')
+        nframes = self.m_image_in_port.get_attribute("NFRAMES")
 
-        if 'PARANG' in non_static:
-            parang = self.m_image_in_port.get_attribute('PARANG')
+        if "PARANG" in non_static:
+            parang = self.m_image_in_port.get_attribute("PARANG")
         else:
             parang = None
 
@@ -263,17 +273,21 @@ class StackCubesModule(ProcessingModule):
 
         start_time = time.time()
         for i, frames in enumerate(nframes):
-            progress(i, len(nframes), 'Stacking images per FITS cube...', start_time)
+            progress(i, len(nframes), "Stacking images per FITS cube...", start_time)
 
-            if self.m_combine == 'mean':
-                im_stack = np.mean(self.m_image_in_port[current:current+frames, ], axis=0)
-            elif self.m_combine == 'median':
-                im_stack = np.median(self.m_image_in_port[current:current+frames, ], axis=0)
+            if self.m_combine == "mean":
+                im_stack = np.mean(
+                    self.m_image_in_port[current : current + frames,], axis=0
+                )
+            elif self.m_combine == "median":
+                im_stack = np.median(
+                    self.m_image_in_port[current : current + frames,], axis=0
+                )
 
             self.m_image_out_port.append(im_stack, data_dim=3)
 
             if parang is not None:
-                parang_new.append(np.mean(parang[current:current+frames]))
+                parang_new.append(np.mean(parang[current : current + frames]))
 
             current += frames
 
@@ -281,16 +295,16 @@ class StackCubesModule(ProcessingModule):
 
         self.m_image_out_port.copy_attributes(self.m_image_in_port)
 
-        if 'INDEX' in non_static:
+        if "INDEX" in non_static:
             index = np.arange(0, nimages, 1, dtype=int)
-            self.m_image_out_port.add_attribute('INDEX', index, static=False)
+            self.m_image_out_port.add_attribute("INDEX", index, static=False)
 
-        if 'NFRAMES' in non_static:
+        if "NFRAMES" in non_static:
             nframes = np.ones(nimages, dtype=int)
-            self.m_image_out_port.add_attribute('NFRAMES', nframes, static=False)
+            self.m_image_out_port.add_attribute("NFRAMES", nframes, static=False)
 
-        if 'PARANG' in non_static:
-            self.m_image_out_port.add_attribute('PARANG', parang_new, static=False)
+        if "PARANG" in non_static:
+            self.m_image_out_port.add_attribute("PARANG", parang_new, static=False)
 
         self.m_image_out_port.close_port()
 
@@ -302,14 +316,16 @@ class DerotateAndStackModule(ProcessingModule):
     """
 
     @typechecked
-    def __init__(self,
-                 name_in: str,
-                 image_in_tag: str,
-                 image_out_tag: str,
-                 derotate: bool = True,
-                 stack: Optional[str] = None,
-                 extra_rot: float = 0.,
-                 dimension: str = 'time') -> None:
+    def __init__(
+        self,
+        name_in: str,
+        image_in_tag: str,
+        image_out_tag: str,
+        derotate: bool = True,
+        stack: Optional[str] = None,
+        extra_rot: float = 0.0,
+        dimension: str = "time",
+    ) -> None:
         """
         Parameters
         ----------
@@ -362,9 +378,9 @@ class DerotateAndStackModule(ProcessingModule):
         """
 
         @typechecked
-        def _initialize(ndim: int,
-                        npix: int) -> Tuple[int, np.ndarray, Optional[np.ndarray],
-                                            Optional[np.ndarray]]:
+        def _initialize(
+            ndim: int, npix: int
+        ) -> Tuple[int, np.ndarray, Optional[np.ndarray], Optional[np.ndarray]]:
 
             if ndim == 2:
                 nimages = 1
@@ -372,7 +388,7 @@ class DerotateAndStackModule(ProcessingModule):
             elif ndim == 3:
                 nimages = self.m_image_in_port.get_shape()[-3]
 
-                if self.m_stack == 'median':
+                if self.m_stack == "median":
                     frames = np.array([0, nimages])
 
                 else:
@@ -382,21 +398,23 @@ class DerotateAndStackModule(ProcessingModule):
                 nimages = self.m_image_in_port.get_shape()[-3]
                 nwave = self.m_image_in_port.get_shape()[-4]
 
-                if self.m_dimension == 'time':
-                    frames = np.linspace(0, nwave, nwave+1)
+                if self.m_dimension == "time":
+                    frames = np.linspace(0, nwave, nwave + 1)
 
-                elif self.m_dimension == 'wavelength':
-                    frames = np.linspace(0, nimages, nimages+1)
+                elif self.m_dimension == "wavelength":
+                    frames = np.linspace(0, nimages, nimages + 1)
 
                 else:
-                    raise ValueError('The dimension should be set to \'time\' or \'wavelength\'.')
+                    raise ValueError(
+                        "The dimension should be set to 'time' or 'wavelength'."
+                    )
 
-            if self.m_stack == 'mean':
+            if self.m_stack == "mean":
                 if ndim == 4:
-                    if self.m_dimension == 'time':
+                    if self.m_dimension == "time":
                         im_tot = np.zeros((nwave, npix, npix))
 
-                    elif self.m_dimension == 'wavelength':
+                    elif self.m_dimension == "wavelength":
                         im_tot = np.zeros((nimages, npix, npix))
 
                 else:
@@ -413,10 +431,10 @@ class DerotateAndStackModule(ProcessingModule):
 
             return nimages, frames, im_tot, im_none
 
-        memory = self._m_config_port.get_attribute('MEMORY')
+        memory = self._m_config_port.get_attribute("MEMORY")
 
         if self.m_derotate:
-            parang = self.m_image_in_port.get_attribute('PARANG')
+            parang = self.m_image_in_port.get_attribute("PARANG")
 
         ndim = self.m_image_in_port.get_ndim()
         npix = self.m_image_in_port.get_shape()[-2]
@@ -425,32 +443,40 @@ class DerotateAndStackModule(ProcessingModule):
 
         start_time = time.time()
         for i, _ in enumerate(frames[:-1]):
-            progress(i, len(frames[:-1]), 'Derotating and/or stacking images...', start_time)
+            progress(
+                i, len(frames[:-1]), "Derotating and/or stacking images...", start_time
+            )
 
             if ndim == 3:
                 # Get the images and ensure they have the correct 3D shape with the following
                 # three dimensions: (batch_size, height, width)
-                images = self.m_image_in_port[frames[i]:frames[i+1], ]
+                images = self.m_image_in_port[frames[i] : frames[i + 1],]
 
             elif ndim == 4:
                 # Process all time frames per exposure at once
-                if self.m_dimension == 'time':
-                    images = self.m_image_in_port[i, :, ]
+                if self.m_dimension == "time":
+                    images = self.m_image_in_port[
+                        i,
+                        :,
+                    ]
 
-                elif self.m_dimension == 'wavelength':
-                    images = self.m_image_in_port[:, i, ]
+                elif self.m_dimension == "wavelength":
+                    images = self.m_image_in_port[
+                        :,
+                        i,
+                    ]
 
             if self.m_derotate:
                 if ndim == 4:
-                    if self.m_dimension == 'time':
-                        angles = -1.*parang + self.m_extra_rot
+                    if self.m_dimension == "time":
+                        angles = -1.0 * parang + self.m_extra_rot
 
-                    elif self.m_dimension == 'wavelength':
+                    elif self.m_dimension == "wavelength":
                         n_wavel = self.m_image_in_port.get_shape()[-4]
-                        angles = np.full(n_wavel, -1.*parang[i]) + self.m_extra_rot
+                        angles = np.full(n_wavel, -1.0 * parang[i]) + self.m_extra_rot
 
                 else:
-                    angles = -parang[frames[i]:frames[i+1]]+self.m_extra_rot
+                    angles = -parang[frames[i] : frames[i + 1]] + self.m_extra_rot
 
                 images = rotate_images(images, angles)
 
@@ -462,42 +488,42 @@ class DerotateAndStackModule(ProcessingModule):
                     self.m_image_out_port.append(images, data_dim=3)
 
                 elif ndim == 4:
-                    if self.m_dimension == 'time':
+                    if self.m_dimension == "time":
                         im_none[i] = images
 
-                    elif self.m_dimension == 'wavelength':
+                    elif self.m_dimension == "wavelength":
                         im_none[:, i] = images
 
-            elif self.m_stack == 'mean':
+            elif self.m_stack == "mean":
                 if ndim == 4:
                     im_tot[i] = np.sum(images, axis=0)
 
                 else:
                     im_tot += np.sum(images, axis=0)
 
-        if self.m_stack == 'mean':
+        if self.m_stack == "mean":
             if ndim == 4:
-                im_stack = im_tot/float(im_tot.shape[0])
+                im_stack = im_tot / float(im_tot.shape[0])
 
-                if self.m_dimension == 'time':
+                if self.m_dimension == "time":
                     self.m_image_out_port.set_all(im_stack[:, np.newaxis, ...])
 
-                elif self.m_dimension == 'wavelength':
+                elif self.m_dimension == "wavelength":
                     self.m_image_out_port.set_all(im_stack[np.newaxis, ...])
 
             else:
-                im_stack = im_tot/float(nimages)
+                im_stack = im_tot / float(nimages)
                 self.m_image_out_port.set_all(im_stack[np.newaxis, ...])
 
-        elif self.m_stack == 'median':
+        elif self.m_stack == "median":
             if ndim == 4:
                 images = self.m_image_in_port[:]
 
-                if self.m_dimension == 'time':
+                if self.m_dimension == "time":
                     im_stack = np.median(images, axis=1)
                     self.m_image_out_port.set_all(im_stack[:, np.newaxis, ...])
 
-                elif self.m_dimension == 'wavelength':
+                elif self.m_dimension == "wavelength":
                     im_stack = np.median(images, axis=0)
                     self.m_image_out_port.set_all(im_stack[np.newaxis, ...])
 
@@ -506,10 +532,10 @@ class DerotateAndStackModule(ProcessingModule):
                 self.m_image_out_port.set_all(im_stack[np.newaxis, ...])
 
         elif self.m_stack is None and ndim == 4:
-            if self.m_dimension == 'time':
+            if self.m_dimension == "time":
                 self.m_image_out_port.set_all(im_none)
 
-            elif self.m_dimension == 'wavelength':
+            elif self.m_dimension == "wavelength":
                 self.m_image_out_port.set_all(im_none)
 
         if self.m_derotate or self.m_stack is not None:
@@ -524,12 +550,14 @@ class CombineTagsModule(ProcessingModule):
     """
 
     @typechecked
-    def __init__(self,
-                 name_in: str,
-                 image_in_tags: List[str],
-                 image_out_tag: str,
-                 check_attr: bool = True,
-                 index_init: bool = False) -> None:
+    def __init__(
+        self,
+        name_in: str,
+        image_in_tags: List[str],
+        image_out_tag: str,
+        check_attr: bool = True,
+        index_init: bool = False,
+    ) -> None:
         """
         Parameters
         ----------
@@ -558,10 +586,12 @@ class CombineTagsModule(ProcessingModule):
         self.m_image_out_port = self.add_output_port(image_out_tag)
 
         if image_out_tag in image_in_tags:
-            raise ValueError('The \'image_out_tag\' should not be present in \'image_in_tags\'.')
+            raise ValueError(
+                "The 'image_out_tag' should not be present in 'image_in_tags'."
+            )
 
         if len(image_in_tags) < 2:
-            raise ValueError('The \'image_in_tags\' should contain at least two tags.')
+            raise ValueError("The 'image_in_tags' should contain at least two tags.")
 
         self.m_image_in_tags = image_in_tags
         self.m_check_attr = check_attr
@@ -580,7 +610,7 @@ class CombineTagsModule(ProcessingModule):
             None
         """
 
-        memory = self._m_config_port.get_attribute('MEMORY')
+        memory = self._m_config_port.get_attribute("MEMORY")
 
         image_in_port = []
         im_shape = []
@@ -590,53 +620,65 @@ class CombineTagsModule(ProcessingModule):
             im_shape.append(image_in_port[i].get_shape()[-2:])
 
         if len(set(im_shape)) > 1:
-            raise ValueError('The size of the images should be the same for all datasets.')
+            raise ValueError(
+                "The size of the images should be the same for all datasets."
+            )
 
         count = 0
         start_time = time.time()
         for i, item in enumerate(self.m_image_in_tags):
-            progress(i, len(self.m_image_in_tags), 'Combining datasets...', start_time)
+            progress(i, len(self.m_image_in_tags), "Combining datasets...", start_time)
 
             nimages = image_in_port[i].get_shape()[0]
             frames = memory_frames(memory, nimages)
 
             for j, _ in enumerate(frames[:-1]):
-                im_tmp = image_in_port[i][frames[j]:frames[j+1], ]
+                im_tmp = image_in_port[i][frames[j] : frames[j + 1],]
                 self.m_image_out_port.append(im_tmp)
 
                 if self.m_index_init:
-                    index = np.arange(frames[j], frames[j+1], 1) + count
+                    index = np.arange(frames[j], frames[j + 1], 1) + count
 
                     if i == 0 and j == 0:
-                        self.m_image_out_port.add_attribute('INDEX', index, static=False)
+                        self.m_image_out_port.add_attribute(
+                            "INDEX", index, static=False
+                        )
                     else:
                         for ind in index:
-                            self.m_image_out_port.append_attribute_data('INDEX', ind)
+                            self.m_image_out_port.append_attribute_data("INDEX", ind)
 
             static_attr = image_in_port[i].get_all_static_attributes()
             non_static_attr = image_in_port[i].get_all_non_static_attributes()
 
             for key in static_attr:
-                status = self.m_image_out_port.check_static_attribute(key, static_attr[key])
+                status = self.m_image_out_port.check_static_attribute(
+                    key, static_attr[key]
+                )
 
                 if status == 1:
-                    self.m_image_out_port.add_attribute(key, static_attr[key], static=True)
+                    self.m_image_out_port.add_attribute(
+                        key, static_attr[key], static=True
+                    )
 
-                elif status == -1 and key[0:7] != 'History':
-                    warnings.warn(f'The static keyword {key} is already used but with a different '
-                                  f'value. It is advisable to only combine tags that descend from '
-                                  f'the same data set.')
+                elif status == -1 and key[0:7] != "History":
+                    warnings.warn(
+                        f"The static keyword {key} is already used but with a different "
+                        f"value. It is advisable to only combine tags that descend from "
+                        f"the same data set."
+                    )
 
             for key in non_static_attr:
                 values = image_in_port[i].get_attribute(key)
                 status = self.m_image_out_port.check_non_static_attribute(key, values)
 
-                if key != 'INDEX' or (key == 'INDEX' and not self.m_index_init):
+                if key != "INDEX" or (key == "INDEX" and not self.m_index_init):
 
                     if self.m_check_attr:
-                        if key in ('PARANG', 'STAR_POSITION', 'INDEX', 'NFRAMES'):
+                        if key in ("PARANG", "STAR_POSITION", "INDEX", "NFRAMES"):
                             if status == 1:
-                                self.m_image_out_port.add_attribute(key, values, static=False)
+                                self.m_image_out_port.add_attribute(
+                                    key, values, static=False
+                                )
 
                             else:
                                 for j in values:
@@ -644,16 +686,22 @@ class CombineTagsModule(ProcessingModule):
 
                         else:
                             if status == 1:
-                                self.m_image_out_port.add_attribute(key, values, static=False)
+                                self.m_image_out_port.add_attribute(
+                                    key, values, static=False
+                                )
 
                             if status == -1:
-                                warnings.warn(f'The non-static keyword {key} is already used but '
-                                              f'with different values. It is advisable to only '
-                                              f'combine tags that descend from the same data set.')
+                                warnings.warn(
+                                    f"The non-static keyword {key} is already used but "
+                                    f"with different values. It is advisable to only "
+                                    f"combine tags that descend from the same data set."
+                                )
 
                     else:
                         if status == 1:
-                            self.m_image_out_port.add_attribute(key, values, static=False)
+                            self.m_image_out_port.add_attribute(
+                                key, values, static=False
+                            )
 
                         else:
                             for j in values:
@@ -661,6 +709,6 @@ class CombineTagsModule(ProcessingModule):
 
             count += nimages
 
-        history = f'number of input tags = {np.size(self.m_image_in_tags)}'
-        self.m_image_out_port.add_history('CombineTagsModule', history)
+        history = f"number of input tags = {np.size(self.m_image_in_tags)}"
+        self.m_image_out_port.add_history("CombineTagsModule", history)
         self.m_image_out_port.close_port()
