@@ -22,16 +22,18 @@ class AttributeReadingModule(ReadingModule):
     attributes to a dataset.
     """
 
-    __author__ = 'Tomas Stolker'
+    __author__ = "Tomas Stolker"
 
     @typechecked
-    def __init__(self,
-                 name_in: str,
-                 data_tag: str,
-                 file_name: str,
-                 attribute: str,
-                 input_dir: Optional[str] = None,
-                 overwrite: bool = False) -> None:
+    def __init__(
+        self,
+        name_in: str,
+        data_tag: str,
+        file_name: str,
+        attribute: str,
+        input_dir: Optional[str] = None,
+        overwrite: bool = False,
+    ) -> None:
         """
         Parameters
         ----------
@@ -79,22 +81,26 @@ class AttributeReadingModule(ReadingModule):
             None
         """
 
-        print('Reading attribute data...', end='')
+        print("Reading attribute data...", end="")
 
         attributes = get_attributes()
 
         if self.m_attribute not in attributes:
-            raise ValueError(f'\'{self.m_attribute}\' is not a valid attribute.')
+            raise ValueError(f"'{self.m_attribute}' is not a valid attribute.")
 
-        if self.m_file_name.endswith('fits'):
+        if self.m_file_name.endswith("fits"):
             values = fits.getdata(os.path.join(self.m_input_location, self.m_file_name))
         else:
-            values = np.loadtxt(os.path.join(self.m_input_location, self.m_file_name),
-                                dtype=attributes[self.m_attribute]['type'])
+            values = np.loadtxt(
+                os.path.join(self.m_input_location, self.m_file_name),
+                dtype=attributes[self.m_attribute]["type"],
+            )
 
         if values.ndim != 1:
-            raise ValueError(f'The input file {self.m_file_name} should contain a 1D list with '
-                             f'attributes.')
+            raise ValueError(
+                f"The input file {self.m_file_name} should contain a 1D list with "
+                f"attributes."
+            )
 
         status = self.m_data_port.check_non_static_attribute(self.m_attribute, values)
 
@@ -105,15 +111,19 @@ class AttributeReadingModule(ReadingModule):
             self.m_data_port.add_attribute(self.m_attribute, values, static=False)
 
         elif status == -1 and not self.m_overwrite:
-            warnings.warn(f'The attribute \'{self.m_attribute}\' is already present. Set the '
-                          f'\'overwrite\' parameter to True in order to overwrite the values with '
-                          f'{self.m_file_name}.')
+            warnings.warn(
+                f"The attribute '{self.m_attribute}' is already present. Set the "
+                f"'overwrite' parameter to True in order to overwrite the values with "
+                f"{self.m_file_name}."
+            )
 
         elif status == 0:
-            warnings.warn(f'The \'{self.m_attribute}\' attribute is already present and '
-                          f'contains the same values as are present in {self.m_file_name}.')
+            warnings.warn(
+                f"The '{self.m_attribute}' attribute is already present and "
+                f"contains the same values as are present in {self.m_file_name}."
+            )
 
-        print(' [DONE]')
+        print(" [DONE]")
 
         self.m_data_port.close_port()
 
@@ -123,15 +133,17 @@ class ParangReadingModule(ReadingModule):
     Module for reading a list of parallactic angles from a FITS or ASCII file.
     """
 
-    __author__ = 'Tomas Stolker'
+    __author__ = "Tomas Stolker"
 
     @typechecked
-    def __init__(self,
-                 name_in: str,
-                 data_tag: str,
-                 file_name: str,
-                 input_dir: Optional[str] = None,
-                 overwrite: bool = False) -> None:
+    def __init__(
+        self,
+        name_in: str,
+        data_tag: str,
+        file_name: str,
+        input_dir: Optional[str] = None,
+        overwrite: bool = False,
+    ) -> None:
         """
         Parameters
         ----------
@@ -175,38 +187,44 @@ class ParangReadingModule(ReadingModule):
             None
         """
 
-        print('Reading parallactic angles...', end='')
+        print("Reading parallactic angles...", end="")
 
-        if self.m_file_name.endswith('fits'):
+        if self.m_file_name.endswith("fits"):
             parang = fits.getdata(os.path.join(self.m_input_location, self.m_file_name))
         else:
             parang = np.loadtxt(os.path.join(self.m_input_location, self.m_file_name))
 
-        print(' [DONE]')
+        print(" [DONE]")
 
         if parang.ndim != 1:
-            raise ValueError(f'The input file {self.m_file_name} should contain a 1D data set with '
-                             f'the parallactic angles.')
+            raise ValueError(
+                f"The input file {self.m_file_name} should contain a 1D data set with "
+                f"the parallactic angles."
+            )
 
-        print(f'Number of angles: {parang.size}')
-        print(f'Rotation range: {parang[0]:.2f} -> {parang[-1]:.2f} deg')
+        print(f"Number of angles: {parang.size}")
+        print(f"Rotation range: {parang[0]:.2f} -> {parang[-1]:.2f} deg")
 
-        status = self.m_data_port.check_non_static_attribute('PARANG', parang)
+        status = self.m_data_port.check_non_static_attribute("PARANG", parang)
 
         if status == 1:
-            self.m_data_port.add_attribute('PARANG', parang, static=False)
+            self.m_data_port.add_attribute("PARANG", parang, static=False)
 
         elif status == -1 and self.m_overwrite:
-            self.m_data_port.add_attribute('PARANG', parang, static=False)
+            self.m_data_port.add_attribute("PARANG", parang, static=False)
 
         elif status == -1 and not self.m_overwrite:
-            warnings.warn(f'The PARANG attribute is already present. Set the \'overwrite\' '
-                          f'parameter to True in order to overwrite the values with '
-                          f'{self.m_file_name}.')
+            warnings.warn(
+                f"The PARANG attribute is already present. Set the 'overwrite' "
+                f"parameter to True in order to overwrite the values with "
+                f"{self.m_file_name}."
+            )
 
         elif status == 0:
-            warnings.warn(f'The PARANG attribute is already present and contains the same values '
-                          f'as are present in {self.m_file_name}.')
+            warnings.warn(
+                f"The PARANG attribute is already present and contains the same values "
+                f"as are present in {self.m_file_name}."
+            )
 
         self.m_data_port.close_port()
 
@@ -216,15 +234,17 @@ class WavelengthReadingModule(ReadingModule):
     Module for reading a list of wavelengths from a FITS or ASCII file.
     """
 
-    __author__ = 'Tomas Stolker'
+    __author__ = "Tomas Stolker"
 
     @typechecked
-    def __init__(self,
-                 name_in: str,
-                 data_tag: str,
-                 file_name: str,
-                 input_dir: Optional[str] = None,
-                 overwrite: bool = False) -> None:
+    def __init__(
+        self,
+        name_in: str,
+        data_tag: str,
+        file_name: str,
+        input_dir: Optional[str] = None,
+        overwrite: bool = False,
+    ) -> None:
         """
         Parameters
         ----------
@@ -268,37 +288,47 @@ class WavelengthReadingModule(ReadingModule):
             None
         """
 
-        print('Reading wavelengths...', end='')
+        print("Reading wavelengths...", end="")
 
-        if self.m_file_name.endswith('fits'):
-            wavelength = fits.getdata(os.path.join(self.m_input_location, self.m_file_name))
+        if self.m_file_name.endswith("fits"):
+            wavelength = fits.getdata(
+                os.path.join(self.m_input_location, self.m_file_name)
+            )
         else:
-            wavelength = np.loadtxt(os.path.join(self.m_input_location, self.m_file_name))
+            wavelength = np.loadtxt(
+                os.path.join(self.m_input_location, self.m_file_name)
+            )
 
-        print(' [DONE]')
+        print(" [DONE]")
 
         if wavelength.ndim != 1:
-            raise ValueError(f'The input file {self.m_file_name} should contain a 1D data set with '
-                             f'the wavelengths.')
+            raise ValueError(
+                f"The input file {self.m_file_name} should contain a 1D data set with "
+                f"the wavelengths."
+            )
 
-        print(f'Number of wavelengths: {wavelength.size}')
-        print(f'Wavelength range: {wavelength[0]:.2f} - {wavelength[-1]:.2f}')
+        print(f"Number of wavelengths: {wavelength.size}")
+        print(f"Wavelength range: {wavelength[0]:.2f} - {wavelength[-1]:.2f}")
 
-        status = self.m_data_port.check_non_static_attribute('WAVELENGTH', wavelength)
+        status = self.m_data_port.check_non_static_attribute("WAVELENGTH", wavelength)
 
         if status == 1:
-            self.m_data_port.add_attribute('WAVELENGTH', wavelength, static=False)
+            self.m_data_port.add_attribute("WAVELENGTH", wavelength, static=False)
 
         elif status == -1 and self.m_overwrite:
-            self.m_data_port.add_attribute('WAVELENGTH', wavelength, static=False)
+            self.m_data_port.add_attribute("WAVELENGTH", wavelength, static=False)
 
         elif status == -1 and not self.m_overwrite:
-            warnings.warn(f'The WAVELENGTH attribute is already present. Set the \'overwrite\' '
-                          f'parameter to True in order to overwrite the values with '
-                          f'{self.m_file_name}.')
+            warnings.warn(
+                f"The WAVELENGTH attribute is already present. Set the 'overwrite' "
+                f"parameter to True in order to overwrite the values with "
+                f"{self.m_file_name}."
+            )
 
         elif status == 0:
-            warnings.warn(f'The WAVELENGTH attribute is already present and contains the same '
-                          f'values as are present in {self.m_file_name}.')
+            warnings.warn(
+                f"The WAVELENGTH attribute is already present and contains the same "
+                f"values as are present in {self.m_file_name}."
+            )
 
         self.m_data_port.close_port()
