@@ -14,8 +14,15 @@ from typeguard import typechecked
 from sklearn.decomposition import PCA
 
 from pynpoint.core.dataio import OutputPort
-from pynpoint.util.multiproc import TaskProcessor, TaskCreator, TaskWriter, TaskResult, \
-                                    TaskInput, MultiprocessingCapsule, to_slice
+from pynpoint.util.multiproc import (
+    TaskProcessor,
+    TaskCreator,
+    TaskWriter,
+    TaskResult,
+    TaskInput,
+    MultiprocessingCapsule,
+    to_slice,
+)
 from pynpoint.util.postproc import postprocessor
 from pynpoint.util.residuals import combine_residuals
 
@@ -27,10 +34,12 @@ class PcaTaskCreator(TaskCreator):
     """
 
     @typechecked
-    def __init__(self,
-                 tasks_queue_in: multiprocessing.JoinableQueue,
-                 num_proc: int,
-                 pca_numbers: Union[np.ndarray, tuple]) -> None:
+    def __init__(
+        self,
+        tasks_queue_in: multiprocessing.JoinableQueue,
+        num_proc: int,
+        pca_numbers: Union[np.ndarray, tuple],
+    ) -> None:
         """
         Parameters
         ----------
@@ -64,14 +73,20 @@ class PcaTaskCreator(TaskCreator):
         if isinstance(self.m_pca_numbers, tuple):
             for i, pca_first in enumerate(self.m_pca_numbers[0]):
                 for j, pca_secon in enumerate(self.m_pca_numbers[1]):
-                    parameters = (((i, i+1, None), (j, j+1, None), (None, None, None)), )
-                    self.m_task_queue.put(TaskInput(tuple((pca_first, pca_secon)), parameters))
+                    parameters = (
+                        ((i, i + 1, None), (j, j + 1, None), (None, None, None)),
+                    )
+                    self.m_task_queue.put(
+                        TaskInput(tuple((pca_first, pca_secon)), parameters)
+                    )
 
             self.create_poison_pills()
 
         else:
             for i, pca_number in enumerate(self.m_pca_numbers):
-                parameters = (((i, i+1, None), (None, None, None), (None, None, None)), )
+                parameters = (
+                    ((i, i + 1, None), (None, None, None), (None, None, None)),
+                )
                 self.m_task_queue.put(TaskInput(pca_number, parameters))
 
             self.create_poison_pills()
@@ -92,17 +107,19 @@ class PcaTaskProcessor(TaskProcessor):
     """
 
     @typechecked
-    def __init__(self,
-                 tasks_queue_in: multiprocessing.JoinableQueue,
-                 result_queue_in: multiprocessing.JoinableQueue,
-                 star_reshape: np.ndarray,
-                 angles: np.ndarray,
-                 scales: Optional[np.ndarray],
-                 pca_model: Optional[PCA],
-                 im_shape: tuple,
-                 indices: Optional[np.ndarray],
-                 requirements: Tuple[bool, bool, bool, bool],
-                 processing_type: str) -> None:
+    def __init__(
+        self,
+        tasks_queue_in: multiprocessing.JoinableQueue,
+        result_queue_in: multiprocessing.JoinableQueue,
+        star_reshape: np.ndarray,
+        angles: np.ndarray,
+        scales: Optional[np.ndarray],
+        pca_model: Optional[PCA],
+        im_shape: tuple,
+        indices: Optional[np.ndarray],
+        requirements: Tuple[bool, bool, bool, bool],
+        processing_type: str,
+    ) -> None:
         """
         Parameters
         ----------
@@ -145,8 +162,7 @@ class PcaTaskProcessor(TaskProcessor):
         self.m_processing_type = processing_type
 
     @typechecked
-    def run_job(self,
-                tmp_task: TaskInput) -> TaskResult:
+    def run_job(self, tmp_task: TaskInput) -> TaskResult:
         """
         Run method of PcaTaskProcessor.
 
@@ -167,42 +183,44 @@ class PcaTaskProcessor(TaskProcessor):
         else:
             pca_number = int(tmp_task.m_input_data)
 
-        residuals, res_rot = postprocessor(images=self.m_star_reshape,
-                                           angles=self.m_angles,
-                                           scales=self.m_scales,
-                                           pca_number=pca_number,
-                                           pca_sklearn=self.m_pca_model,
-                                           im_shape=self.m_im_shape,
-                                           indices=self.m_indices,
-                                           processing_type=self.m_processing_type)
+        residuals, res_rot = postprocessor(
+            images=self.m_star_reshape,
+            angles=self.m_angles,
+            scales=self.m_scales,
+            pca_number=pca_number,
+            pca_sklearn=self.m_pca_model,
+            im_shape=self.m_im_shape,
+            indices=self.m_indices,
+            processing_type=self.m_processing_type,
+        )
 
         # differentiate between IFS data or Mono-Wavelength data
         if res_rot.ndim == 3:
             res_output = np.zeros((4, res_rot.shape[-2], res_rot.shape[-1]))
 
         else:
-            res_output = np.zeros((4, len(self.m_star_reshape),
-                                   res_rot.shape[-2], res_rot.shape[-1]))
+            res_output = np.zeros(
+                (4, len(self.m_star_reshape), res_rot.shape[-2], res_rot.shape[-1])
+            )
 
         if self.m_requirements[0]:
-            res_output[0, ] = combine_residuals(method='mean',
-                                                res_rot=res_rot)
+            res_output[0,] = combine_residuals(method="mean", res_rot=res_rot)
 
         if self.m_requirements[1]:
-            res_output[1, ] = combine_residuals(method='median',
-                                                res_rot=res_rot)
+            res_output[1,] = combine_residuals(method="median", res_rot=res_rot)
 
         if self.m_requirements[2]:
-            res_output[2, ] = combine_residuals(method='weighted',
-                                                res_rot=res_rot,
-                                                residuals=residuals,
-                                                angles=self.m_angles)
+            res_output[2,] = combine_residuals(
+                method="weighted",
+                res_rot=res_rot,
+                residuals=residuals,
+                angles=self.m_angles,
+            )
 
         if self.m_requirements[3]:
-            res_output[3, ] = combine_residuals(method='clipped',
-                                                res_rot=res_rot)
+            res_output[3,] = combine_residuals(method="clipped", res_rot=res_rot)
 
-        sys.stdout.write('.')
+        sys.stdout.write(".")
         sys.stdout.flush()
 
         return TaskResult(res_output, tmp_task.m_job_parameter[0])
@@ -215,14 +233,16 @@ class PcaTaskWriter(TaskWriter):
     """
 
     @typechecked
-    def __init__(self,
-                 result_queue_in: multiprocessing.JoinableQueue,
-                 mean_out_port: Optional[OutputPort],
-                 median_out_port: Optional[OutputPort],
-                 weighted_out_port: Optional[OutputPort],
-                 clip_out_port: Optional[OutputPort],
-                 data_mutex_in: multiprocessing.Lock,
-                 requirements: Tuple[bool, bool, bool, bool]) -> None:
+    def __init__(
+        self,
+        result_queue_in: multiprocessing.JoinableQueue,
+        mean_out_port: Optional[OutputPort],
+        median_out_port: Optional[OutputPort],
+        weighted_out_port: Optional[OutputPort],
+        clip_out_port: Optional[OutputPort],
+        data_mutex_in: multiprocessing.Lock,
+        requirements: Tuple[bool, bool, bool, bool],
+    ) -> None:
         """
         Constructor of PcaTaskWriter.
 
@@ -281,9 +301,12 @@ class PcaTaskWriter(TaskWriter):
             with self.m_data_mutex:
                 res_slice = to_slice(next_result.m_position)
                 if next_result.m_position[1][0] is None:
-                    res_slice = (next_result.m_position[0][0])
+                    res_slice = next_result.m_position[0][0]
                 else:
-                    res_slice = (next_result.m_position[0][0], next_result.m_position[1][0])
+                    res_slice = (
+                        next_result.m_position[0][0],
+                        next_result.m_position[1][0],
+                    )
 
                 if self.m_requirements[0]:
                     self.m_mean_out_port._check_status_and_activate()
@@ -314,20 +337,22 @@ class PcaMultiprocessingCapsule(MultiprocessingCapsule):
     """
 
     @typechecked
-    def __init__(self,
-                 mean_out_port: Optional[OutputPort],
-                 median_out_port: Optional[OutputPort],
-                 weighted_out_port: Optional[OutputPort],
-                 clip_out_port: Optional[OutputPort],
-                 num_proc: int,
-                 pca_numbers: Union[tuple, np.ndarray],
-                 pca_model: Optional[PCA],
-                 star_reshape: np.ndarray,
-                 angles: np.ndarray,
-                 scales: Optional[np.ndarray],
-                 im_shape: tuple,
-                 indices: Optional[np.ndarray],
-                 processing_type: str) -> None:
+    def __init__(
+        self,
+        mean_out_port: Optional[OutputPort],
+        median_out_port: Optional[OutputPort],
+        weighted_out_port: Optional[OutputPort],
+        clip_out_port: Optional[OutputPort],
+        num_proc: int,
+        pca_numbers: Union[tuple, np.ndarray],
+        pca_model: Optional[PCA],
+        star_reshape: np.ndarray,
+        angles: np.ndarray,
+        scales: Optional[np.ndarray],
+        im_shape: tuple,
+        indices: Optional[np.ndarray],
+        processing_type: str,
+    ) -> None:
         """
         Constructor of PcaMultiprocessingCapsule.
 
@@ -398,8 +423,7 @@ class PcaMultiprocessingCapsule(MultiprocessingCapsule):
         super(PcaMultiprocessingCapsule, self).__init__(None, None, num_proc)
 
     @typechecked
-    def create_writer(self,
-                      image_out_port: None) -> PcaTaskWriter:
+    def create_writer(self, image_out_port: None) -> PcaTaskWriter:
         """
         Method to create an instance of PcaTaskWriter.
 
@@ -414,17 +438,18 @@ class PcaMultiprocessingCapsule(MultiprocessingCapsule):
             PCA task writer.
         """
 
-        return PcaTaskWriter(self.m_result_queue,
-                             self.m_mean_out_port,
-                             self.m_median_out_port,
-                             self.m_weighted_out_port,
-                             self.m_clip_out_port,
-                             self.m_data_mutex,
-                             self.m_requirements)
+        return PcaTaskWriter(
+            self.m_result_queue,
+            self.m_mean_out_port,
+            self.m_median_out_port,
+            self.m_weighted_out_port,
+            self.m_clip_out_port,
+            self.m_data_mutex,
+            self.m_requirements,
+        )
 
     @typechecked
-    def init_creator(self,
-                     image_in_port: None) -> PcaTaskCreator:
+    def init_creator(self, image_in_port: None) -> PcaTaskCreator:
         """
         Method to create an instance of PcaTaskCreator.
 
@@ -439,9 +464,7 @@ class PcaMultiprocessingCapsule(MultiprocessingCapsule):
             PCA task creator.
         """
 
-        return PcaTaskCreator(self.m_tasks_queue,
-                              self.m_num_proc,
-                              self.m_pca_numbers)
+        return PcaTaskCreator(self.m_tasks_queue, self.m_num_proc, self.m_pca_numbers)
 
     @typechecked
     def create_processors(self) -> List[PcaTaskProcessor]:
@@ -458,15 +481,19 @@ class PcaMultiprocessingCapsule(MultiprocessingCapsule):
 
         for _ in range(self.m_num_proc):
 
-            processors.append(PcaTaskProcessor(self.m_tasks_queue,
-                                               self.m_result_queue,
-                                               self.m_star_reshape,
-                                               self.m_angles,
-                                               self.m_scales,
-                                               self.m_pca_model,
-                                               self.m_im_shape,
-                                               self.m_indices,
-                                               self.m_requirements,
-                                               self.m_processing_type))
+            processors.append(
+                PcaTaskProcessor(
+                    self.m_tasks_queue,
+                    self.m_result_queue,
+                    self.m_star_reshape,
+                    self.m_angles,
+                    self.m_scales,
+                    self.m_pca_model,
+                    self.m_im_shape,
+                    self.m_indices,
+                    self.m_requirements,
+                    self.m_processing_type,
+                )
+            )
 
         return processors
