@@ -12,22 +12,26 @@ class TestDataStorage:
     def setup_class(self) -> None:
 
         self.limit = 1e-10
-        self.test_data = os.path.dirname(__file__) + '/PynPoint_database.hdf5'
+        self.test_data = os.path.dirname(__file__) + "/PynPoint_database.hdf5"
 
     def test_create_storage_with_existing_database(self) -> None:
 
         np.random.seed(1)
         images = np.random.normal(loc=0, scale=2e-4, size=(10, 100, 100))
 
-        with h5py.File(self.test_data, 'w') as hdf_file:
-            hdf_file.create_dataset('images', data=images)
+        with h5py.File(self.test_data, "w") as hdf_file:
+            hdf_file.create_dataset("images", data=images)
 
         storage = DataStorage(self.test_data)
         storage.open_connection()
-        data = storage.m_data_bank['images']
+        data = storage.m_data_bank["images"]
 
-        assert data[0, 0, 0] == pytest.approx(0.00032486907273264834, rel=self.limit, abs=0.)
-        assert np.mean(data) == pytest.approx(1.0506056979365338e-06, rel=self.limit, abs=0.)
+        assert data[0, 0, 0] == pytest.approx(
+            0.00032486907273264834, rel=self.limit, abs=0.0
+        )
+        assert np.mean(data) == pytest.approx(
+            1.0506056979365338e-06, rel=self.limit, abs=0.0
+        )
 
         os.remove(self.test_data)
 
@@ -35,10 +39,12 @@ class TestDataStorage:
 
         storage = DataStorage(self.test_data)
         storage.open_connection()
-        storage.m_data_bank['data'] = [0, 1, 2, 5, 7]
+        storage.m_data_bank["data"] = [0, 1, 2, 5, 7]
 
-        assert storage.m_data_bank['data'][2] == 2
-        assert list(storage.m_data_bank.keys()) == ['data', ]
+        assert storage.m_data_bank["data"][2] == 2
+        assert list(storage.m_data_bank.keys()) == [
+            "data",
+        ]
 
         storage.close_connection()
 
@@ -46,7 +52,7 @@ class TestDataStorage:
 
     def test_create_storage_with_wrong_location(self) -> None:
 
-        file_in = '/test/test.hdf5'
+        file_in = "/test/test.hdf5"
 
         with pytest.raises(AssertionError):
             DataStorage(file_in)
