@@ -12,12 +12,12 @@ class TestInputPort:
     def setup_class(self) -> None:
 
         self.limit = 1e-10
-        self.test_dir = os.path.dirname(__file__) + '/'
+        self.test_dir = os.path.dirname(__file__) + "/"
 
         create_random(self.test_dir)
-        create_config(self.test_dir+'PynPoint_config.ini')
+        create_config(self.test_dir + "PynPoint_config.ini")
 
-        file_in = os.path.dirname(__file__) + '/PynPoint_database.hdf5'
+        file_in = os.path.dirname(__file__) + "/PynPoint_database.hdf5"
 
         self.storage = DataStorage(file_in)
 
@@ -28,36 +28,43 @@ class TestInputPort:
     def test_create_instance_access_data(self) -> None:
 
         with pytest.raises(ValueError) as error:
-            InputPort('config', self.storage)
+            InputPort("config", self.storage)
 
-        assert str(error.value) == 'The tag name \'config\' is reserved for the central ' \
-                                   'configuration of PynPoint.'
+        assert (
+            str(error.value) == "The tag name 'config' is reserved for the central "
+            "configuration of PynPoint."
+        )
 
         with pytest.raises(ValueError) as error:
-            InputPort('fits_header', self.storage)
+            InputPort("fits_header", self.storage)
 
-        assert str(error.value) == 'The tag name \'fits_header\' is reserved for storage of the ' \
-                                   'FITS headers.'
+        assert (
+            str(error.value)
+            == "The tag name 'fits_header' is reserved for storage of the "
+            "FITS headers."
+        )
 
-        port = InputPort('images', self.storage)
+        port = InputPort("images", self.storage)
 
-        assert port[0, 0, 0] == pytest.approx(0.00032486907273264834, rel=self.limit, abs=0.)
+        assert port[0, 0, 0] == pytest.approx(
+            0.00032486907273264834, rel=self.limit, abs=0.0
+        )
 
         data = np.mean(port.get_all())
-        assert data == pytest.approx(1.1824138000882435e-05, rel=self.limit, abs=0.)
+        assert data == pytest.approx(1.1824138000882435e-05, rel=self.limit, abs=0.0)
 
         assert len(port[0:2, 0, 0]) == 2
         assert port.get_shape() == (5, 11, 11)
 
-        assert port.get_attribute('PIXSCALE') == 0.01
-        assert port.get_attribute('PARANG')[0] == 0.
+        assert port.get_attribute("PIXSCALE") == 0.01
+        assert port.get_attribute("PARANG")[0] == 0.0
 
         with pytest.warns(UserWarning):
-            assert port.get_attribute('none') is None
+            assert port.get_attribute("none") is None
 
     def test_create_instance_access_non_existing_data(self) -> None:
 
-        port = InputPort('test', self.storage)
+        port = InputPort("test", self.storage)
 
         with pytest.warns(UserWarning):
             assert port[0, 0, 0] is None
@@ -69,7 +76,7 @@ class TestInputPort:
             assert port.get_shape() is None
 
         with pytest.warns(UserWarning):
-            assert port.get_attribute('num_files') is None
+            assert port.get_attribute("num_files") is None
 
         with pytest.warns(UserWarning):
             assert port.get_all_non_static_attributes() is None
@@ -79,7 +86,7 @@ class TestInputPort:
 
     def test_create_instance_no_data_storage(self) -> None:
 
-        port = InputPort('test')
+        port = InputPort("test")
 
         with pytest.warns(UserWarning):
             assert port[0, 0, 0] is None
